@@ -24,6 +24,7 @@
 #include "BKE_attribute.hh"
 #include "BKE_attribute_math.hh"
 #include "BKE_bvhutils.hh"
+#include "BKE_deform.hh"
 #include "BKE_mesh.hh"
 #include "BKE_mesh_remesh_voxel.hh" /* own include */
 #include "BKE_mesh_sample.hh"
@@ -496,7 +497,7 @@ static void gather_attributes(const Span<StringRef> ids,
 {
   for (const StringRef id : ids) {
     const GVArraySpan src = *src_attributes.lookup(id, domain);
-    const eCustomDataType type = cpp_type_to_custom_data_type(src.type());
+    const AttrType type = cpp_type_to_attribute_type(src.type());
     GSpanAttributeWriter dst = dst_attributes.lookup_or_add_for_write_only_span(id, domain, type);
     attribute_math::gather(src, index_map, dst.span);
     dst.finish();
@@ -572,6 +573,10 @@ void mesh_remesh_reproject_attributes(const Mesh &src, Mesh &dst)
       Array<int> map(dst.verts_num);
       find_nearest_verts(
           src_positions, src_corner_verts, src_corner_tris, dst_positions, vert_nearest_tris, map);
+      /* Copy vertex group names (otherwise `MeshVertexGroupsAttributeProvider` wont find them -
+       * and these would show up as regular attributes afterwards). "vertex_group_active_index" is
+       * taken care of via #BKE_mesh_copy_parameters(). */
+      BKE_defgroup_copy_list(&dst.vertex_group_names, &src.vertex_group_names);
       gather_attributes(point_ids, src_attributes, AttrDomain::Point, map, dst_attributes);
     }
 
